#
# spec file for package ImHex
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _plutovg_version 0.0.4

%define sover 1_37_4
Name:           ImHex
Version:        1.37.4
Release:        1.3
Summary:        A Hex Editor for Reverse Engineers, Programmers
License:        GPL-2.0-only
Group:          Development/Tools/Other
URL:            https://imhex.werwolv.net/
Source0:        %{name}-%{version}.tar.xz
Source1:        https://github.com/sammycage/plutovg/archive/refs/tags/v%{_plutovg_version}.tar.gz#/plutovg-%{_plutovg_version}.tar.gz
# Patch to workaround libLLVMDemangle.so() not found which may be a SUSE issue
Source99:       %{name}-rpmlintrc
Patch0:         ImHex-llvm_demangler-linking.patch
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  file-devel >= 5.39
BuildRequires:  gcc-c++
BuildRequires:  git-core
BuildRequires:  hicolor-icon-theme
BuildRequires:  llvm-devel
BuildRequires:  mbedtls-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(fmt)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glfw3)
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libcurl) >= 7.76.1
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(nlohmann_json) >= 3.10.2
BuildRequires:  pkgconfig(yara)
### bundled stuff
# needs capstone 5.x
Provides:       bundled(capstone) = 5.0.0-rc2
Provides:       bundled(gnulib)
Provides:       bundled(imgui)
Provides:       bundled(intervaltree)
Provides:       bundled(libpl)
Provides:       bundled(libromfs)
Provides:       bundled(microtar)
Provides:       bundled(plutovg) = %{_plutovg_version}

%description
A hex editor with a custom C++-like pattern language for parsing and highlighting a file's content,
data import and export, string search, file hashing, disassembler support, bookmarks, data analyzers,
demanglers, color picker, regex replacer, calculator, built-in cheat sheets and eye friendly UI.

%package -n libimhex%{sover}
Summary:        Shared library for ImHex
Group:          System/Libraries

%description -n libimhex%{sover}
libimhex is a C++ library library providing functions needed for ImHex.

%package devel
Summary:        Development files for ImHex
Group:          Development/Libraries/C and C++
Requires:       libimhex%{sover} = %{version}-%{release}

%description devel
This package contains libraries and header files for developing
applications that want to make use of ImHex.

%prep
%setup -q
%autopatch -p1
# Clean bundled libs
rm -Rv lib/third_party/{fmt,llvm-demangle,yara}

mkdir prefetched
pushd prefetched
for s in %{SOURCE1}; do tar -xf "$s"; done

%build
echo %{version} > VERSION
%cmake \
  -DIMHEX_OFFLINE_BUILD=ON \
  -DUSE_SYSTEM_NLOHMANN_JSON=ON \
  -DUSE_SYSTEM_CURL=ON \
  -DUSE_SYSTEM_FMT=ON \
  -DUSE_SYSTEM_CAPSTONE=OFF \
  -DUSE_SYSTEM_YARA=ON \
  -DUSE_SYSTEM_LLVM=ON \
  -DFETCHCONTENT_SOURCE_DIR_PLUTOVG=../prefetched/plutovg-%{_plutovg_version}
%cmake_build

%install
%cmake_install
%fdupes %{buildroot}%{_datadir}/imhex/sdk

%ldconfig_scriptlets -n libimhex%{sover}

%files
%doc README.md
%license LICENSE
%exclude %{_datadir}/licenses/imhex/LICENSE
%{_bindir}/imhex
%exclude %{_bindir}/imhex-updater
%dir %{_libdir}/imhex
%dir %{_libdir}/imhex/plugins
%{_libdir}/imhex/plugins/builtin.hexplug
%{_libdir}/imhex/plugins/decompress.hexplug
%{_libdir}/imhex/plugins/diffing.hexplug
%{_libdir}/imhex/plugins/disassembler.hexplug
%{_libdir}/imhex/plugins/fonts.hexpluglib
%{_libdir}/imhex/plugins/hashes.hexplug
%{_libdir}/imhex/plugins/script_loader.hexplug
%{_libdir}/imhex/plugins/ui.hexpluglib
%{_libdir}/imhex/plugins/visualizers.hexplug
%{_libdir}/imhex/plugins/yara_rules.hexplug
%{_datadir}/metainfo/net.werwolv.imhex.appdata.xml
%{_datadir}/metainfo/net.werwolv.imhex.metainfo.xml
%{_datadir}/mime/packages/imhex.xml
%{_datadir}/pixmaps/imhex.svg
%{_datadir}/applications/imhex.desktop

%files -n libimhex%{sover}
%{_libdir}/libimhex.so.%{version}

%files devel
%{_libdir}/libimhex.so
%dir %{_datadir}/imhex
%{_datadir}/imhex/sdk

%changelog
* Wed Feb 26 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 1.37.4
  * Fixed a regression with the frame rate limiting logic which
    caused ImHex to use a lot of CPU on Idle.
  * Fixed a few issues with OpenGL texture deallocations.
- Update to version 1.37.3
  * Fixed a crash when closing ImHex, mainly noticeable on macOS.
  * Fixed an ID collision when multiple fonts with the same name
    are installed on the system.
* Mon Feb 24 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 1.37.2
  Bugfix release
  * https://github.com/WerWolv/ImHex/compare/v1.37.1...v1.37.2
* Mon Feb 24 2025 Martin Hauke <mardnh@gmx.de>
- Don't package imhex-updater.
* Wed Feb 19 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 1.37.1
  Bugfix release
  * https://github.com/WerWolv/ImHex/compare/v1.37.0...v1.37.1
* Mon Feb 17 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 1.37.0:
  Features
  * ImHex now properly supports HiDPI scaling.
  * You can now set separate fonts for the main UI, the Hex Editor
    and the Pattern Editor.
  * Added messaging support.
  Improvements
  * Replaced the app icon with the one from the Papyrus Icon
    Project.
  Pattern Language
  * The evaluator now tries to keep as many patterns as it
    possibly can when an error occurs
  Bugfixes
  * Lots of fixed bugs
  Full changelog
  * https://github.com/WerWolv/ImHex/releases/tag/v1.37.0
- Use distro provided nlohmann_json
* Sat Dec 28 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.36.2:
  * https://github.com/WerWolv/ImHex/releases/tag/v1.36.2
  * https://github.com/WerWolv/ImHex/releases/tag/v1.36.1
* Wed Dec 25 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.36.0
  * https://github.com/WerWolv/ImHex/releases/tag/v1.36.0
* Thu Nov  7 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.35.4
  * https://github.com/WerWolv/ImHex/releases/tag/v1.35.4
- Update to version 1.35.3
  * https://github.com/WerWolv/ImHex/releases/tag/v1.35.3
- Update to version 1.35.2
  * https://github.com/WerWolv/ImHex/releases/tag/v1.35.2
- Update to version 1.35.1
  * https://github.com/WerWolv/ImHex/releases/tag/v1.35.1
- Update to version 1.35.0
  * https://github.com/WerWolv/ImHex/releases/tag/v1.35.0
- Update to version 1.34.0
  * https://github.com/WerWolv/ImHex/releases/tag/v1.34.0
- Update to version 1.33.0
  * https://github.com/WerWolv/ImHex/releases/tag/v1.33.0
- Drop patches (not longer needed)
  * llvm_demangler_signature.patch
  * installation.patch
- Add patch:
  * ImHex-llvm_demangler-linking.patch
* Thu Dec 28 2023 mardnh@gmx.de
- Update to version 1.32.1:
  Bugfix release
  * ImHex doesn't crash anymore when opening the diffing view.
* Thu Dec 28 2023 mardnh@gmx.de
- Update to version 1.32.0:
  Additions
  * Added a shortcut manager to the Settings.
  * Added Markdown reports.
  * Greatly improve the Undo/Redo system.
  * Added option to specify custom highlighting rules to set the
    foreground color of bytes according to boolean equations.
  * Added Workspaces.
  * Added a minimal layout.
  * Added automatic backups.
  * Added a interactive tutorial.
  Improvements
  * Rewrote, restructured and redesigned Settings interface.
  * Updated ImGui to v1.90.
  * Lots and lots of UI improvements.
  * Lots and lots of internal rewrites, restructures and refactors.
  * Scrolling in the hex editor now works much nicer.
  Bug Fixes
  * Fixed issue where no provider was being selected when closing
    a provider in some cases.
  * Moving windows that overlap with the main window title bar no
    longer move the main window.
  Pattern Language
  * Ongoing: Big parts of the Pattern Language are currently being
    rewritten in order to drastically improve usability, speed and
    reliability.
  * Added support for writing back to the data source.
  * Added support for decompressing data.
- Drop patch:
  * llvm_demangler_signature.patch (no longer needed)
- Add ImHex-rpmlintrc to workaround some sdk related rpmlint
  warnings.
* Mon Nov 20 2023 Michael Gumsley <gumsley_6@hotmail.com>
- Fix openSUSE Tumbleweed build:
  * Backport fix from upstream commit
    498d8c1d65c1a74c3f2c21806803254c61df6d01 regarding
    llvm::itaniumDemangle signature used in crash_handlers.cpp
* Mon Sep 25 2023 mardnh@gmx.de
- Update to version 1.31.0:
  Additions
  * Added a command line interface to ImHex.
  * Added initial support for .NET scripts.
  * Added Achievements.
  * Added a new and much nicer splash screen.
  * Allow memory files to be saved to project files and be renamed .
  * Added built-in logging console.
  * Allow hex editor data visualizers to be switched to big-endian
    mode.
  * Upgraded to Capstone V5.
  * Encoding names are now being displayed in the header of the
    hex editor.
  * Added a "Update All" button to the content store.
  * Linux now uses the GTK filepicker whenever possible.
  * The hex editor editing mode is now being entered when
    pressing Enter.
  * Added a setting to remember the current main window size and
    position.
  * Added option to fill a selected region with bytes.
  * Added option to switch between human-readable sizes and bytes
    in the hex editor footer.
  * Added authors and descriptions to things in the content store
  * Added shortcuts to switch between providers, evaluate
    patterns and interact with the pattern debugger
  Improvements
  * Improved the data information diagrams look and field.
  * Multi-window support is now being disabled properly by
    default on Linux.
  * Plugins are now being loaded asynchronously to improve
    startup times.
  * Pattern console is automatically scrolled to the bottom now
    when new lines are being added.
  * Unidentifiable data is being handled better now in the data
    information view.
  * Allow hex editor view to be scrolled slightly past the end.
  * Made demangler results selectable and copyable.
  * ImHex should now exit cleanly when crashing.
  * Bytes per row count setting in the hex editor is being
    remembered now.
  Bug Fixes
  * Fixed raw disk provider not working correctly on non-windows
    platforms.
  * Fixed disassembler view not clearning selection when typing
    in the region field.
  * Fixed page count displaying wrongly in empty files.
  * Fixed crash when trying to paste bytes without a selection.
  * Fixed occasional crash when evaluating patterns.
  * Fixed scaling not being applied properly in some cases.
  * Fixed bookmarks not being loaded correctly from project files.
  * Fixed menu bar being scrollable sideways.
  * Fixed loading projects when an existing project is loaded
    already.
  * Fixed issues where the cursor started flickering when hovering
    certain elements.
  * Fixed crash when clicking on "Open in new view" in a bookmark.
  * Fixed occasional crash when loading incorrect data processor
    node files.
  * Fixed writing to non-zero pages in the hex editor when a custom
    base address has been set.
  * Fixed issue where libmagic dumped a bunch of compiled files
    into the cwd on Linux and macOS.
  * Fixed endianess of all CRC hashes.
  * Fixed highest/lowest entropy block address in the data
    information view being wrong.
  * Fixed issue where downloading items from the store was
    suceptible for path traversal.
  * Fixed various data processor issues.
  Pattern Language
  * Added typenameof operator.
  * Added [[hex::favorite]] attribute to mark patterns as favorites
    directly.
  * Added [[hex::group]] attribute to add patterns to custom groups
    in the pattern data view.
  * Added single-stepping feature to pattern debugger.
  * Added coordinates visualizer.
  * Added timestamp visualizer.
  * Images in the pattern image and bitmap visualizer can now be
    scaled.
  * Added various new inline visualizers such as "color", "guage"
    and "button".
  * Format functions are no longer being evaluated during
    highlighting.
  * Sections without a name are being hidden now and treated as
    "internal" sections
  * Added [[hex::spec_name]] attribute to document names for
    pattern variables taken from the documentation.
  * Added string in/out variables.
  * Fixed issue where pattern local variables sometimes allocated
    huge amounts of memory.
* Mon Jul  3 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.30.1:
  * https://github.com/WerWolv/ImHex/releases/tag/v1.30.1
  * https://github.com/WerWolv/ImHex/releases/tag/v1.30.0
* Fri Jun  9 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.29.0
  * https://github.com/WerWolv/ImHex/releases/tag/v1.29.0
* Fri Apr  7 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.28.0
  * https://github.com/WerWolv/ImHex/releases/tag/v1.28.0
* Wed Feb 15 2023 mardnh@gmx.de
- Update to version 1.27.1
  * Bugfix Release
* Sun Feb 12 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.27.0:
  * https://github.com/WerWolv/ImHex/releases/tag/v1.27.0
* Thu Jan  5 2023 mardnh@gmx.de
- Update to version 1.26.2:
  Additions
  * Added a "Save Project" menu entry to quickly save the current
    project without specifying a path.
  * Added byte Type distribution, digram and layered distribution
    plots to information view.
  * Added support for pasting byte strings with 0x prefixes or
    commas inbetween in the hex editor view.
  * Added native theming support
    + New themes can now simply be placed in the %%IMHEX%%/themes
    folder for them to be loaded.
  Improvements
  * ImHex now automatically disables unicode support if the used
    GPU doesn't have enough VRAM to load all glyphs.
  * The localization system has been completely revamped and now
    uses simple json files.
  * Improved speed of entropy graph calculation
  * Improved German translation.
  * Improved Chinese (Simplified) translation.
  Bug Fixes
  * Fixed building with LTO enabled.
  * Fixed patterns not appearing if pattern editor is not visible.
  * Fixed a crash when closing a section view while bytes were
    selected.
  * Fixed file provider adding additional zero bytes at the end of
    the file when saving.
  * Fixed issues where the hex editor view would sometimes jump
    back to the start of the file after searching.
  * Fixed searching for negative floating point values.
  * Fixed a crash when printing NULL bytes to the pattern console.
  * Fixed bookmarks displaying too many bytes in some cases.
  * Fixed saving of projects to paths containing non-ASCII
    characters.
  * Fixed various issues where iterators and containers got
    accessed incorrectly which could lead to issues and crashes.
  * Fixed template types being placable through the hex editor
    right click menu.
  Pattern Language
  * Added the ability to modify values in the pattern data view.
  * Added visualizers.
* Tue Nov 15 2022 Martin Hauke <mardnh@gmx.de>
- Reenable LTO
* Mon Nov 14 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.25.0:
  Highlights
  * custom Sections / Back Buffers for the pattern language which
    allows you to allocate dynamic memory, write data to it and
    then place patterns in there. Helpful for compressed, encrypted
    or otherwise transformed file formats.
  * New view providers to open a region of an existing provider in
    a new tab.
  * Full Changelog
    https://github.com/WerWolv/ImHex/releases/tag/v1.25.0
* Sun Oct 30 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.24.3
  * https://github.com/WerWolv/ImHex/releases/tag/v1.24.3
- Drop patches:
  * system-libs.patch
  * memleak.patch
  * installation.patch
- Switch to a tarball created with the tar_scm since we need also
  need the bundled libs.
- Introduce subpackage for libimhex
* Sat Feb 20 2021 Matthias Mailänder <mailaender@opensuse.org>
- update to 1.7.0
- add installation.patch
- add memleak.patch
- add system-libs.patch
* Sat Jan 30 2021 Matthias Mailänder <matthias@mailaender.name>
- Update to version 1.6.1
- Drop llvm-demangle.patch
- Remove the wrapper script
* Wed Dec  9 2020 Matthias Mailänder <mailaender@opensuse.org>
- Udate to version 1.5.0
- Drop license.patch
* Tue Dec  8 2020 Matthias Mailänder <mailaender@opensuse.org>
- Add icons and desktop shortcuts
* Sat Dec  5 2020 Matthias Mailänder <mailaender@opensuse.org>
- initial packaging of version 1.4.0
